/*
 * IcmpMutex.h
 *
 * Copyright (c) Verax Systems.
 * All rights reserved.
 *
 * This software is furnished under a license. Use, duplication,
 * disclosure and all other uses are restricted to the rights
 * specified in the written license agreement.
 */
/**
 * @file IcmpMutex.h
 *
 * @brief ICMP API: mutex implementation
 *
 * File contains functions creating/releasing mutex with rights granted fro everyone.
 * Such mutex may be used by all processes on computer.
 * 
 */


#ifndef __ICMP_MUTEX_H__
#define __ICMP_MUTEX_H__

#include <windows.h>

/**
 * @brief The name of mutex used by this library.
 */
#define ICMP_MUTEX_NAME   "VERAX_ICMP_MUTEX"     


/**
 * @brief Security descriptor string for mutex creation.
 */
#define ICMP_MUTEX_RIGHTS       "D:(A;NP;0x001f0001;;;WD)"

/**
 * @brief Create mutex
 *
 * Function creates or opens named mutex object. If new mutex is created
 * it has assigned public name #ICMP_MUTEX_NAME and proper access rights
 * that allows anybody open the mutex.
 * In order to release resources allocated by this function the IcmpCloseMutex()
 * must be executed.
 *
 * @return handle to mutex object
 */
HANDLE IcmpCreateMutex(void);


/**
 * @brief Close mutex created by IcmpCreateMutex() function.

 * @param handle mutex handle
 * @return TRUE on success or FALSE on failure
 * @remarks <description>
 */
BOOL   IcmpCloseMutex(HANDLE handle);


/**
 * @brief Obtain lock access on mutex
 *
 * @param handle the handle to mutex object        
 * @return TRUE on success or FALSE on failure
 */
BOOL   IcmpLockMutex(HANDLE handle);


/**
 * @brief Release lock to mutex object.
 *
 * @param handle the handle to mutex object        
 * @return TRUE on success or FALSE on failure
 */
BOOL   IcmpUnlockMutex(HANDLE handle);

#endif
